@@ -32,7 +32,6 @@
 
 #include <libgames-support/games-conf.h>
 #include <libgames-support/games-frame.h>
-#include <libgames-support/games-gtk-compat.h>
 #include <libgames-support/games-controls.h>
 #include <libgames-support/games-sound.h>
 
@@ -44,9 +43,9 @@
 #define DEFAULT_LEVEL_PLAYER1  LEVEL_HUMAN
 #define DEFAULT_LEVEL_PLAYER2  LEVEL_WEAK
 #define DEFAULT_THEME_ID       0
-#define DEFAULT_KEY_LEFT       GDK_Left
-#define DEFAULT_KEY_RIGHT      GDK_Right
-#define DEFAULT_KEY_DROP       GDK_Down
+#define DEFAULT_KEY_LEFT       GDK_KEY_Left
+#define DEFAULT_KEY_RIGHT      GDK_KEY_Right
+#define DEFAULT_KEY_DROP       GDK_KEY_Down
 #define DEFAULT_DO_SOUND       TRUE
 #define DEFAULT_DO_ANIMATE     TRUE
 
@@ -282,7 +281,6 @@ prefsbox_open (void)
 					  GTK_DIALOG_DESTROY_WITH_PARENT,
 					  GTK_STOCK_CLOSE,
 					  GTK_RESPONSE_ACCEPT, NULL);
-  gtk_dialog_set_has_separator (GTK_DIALOG (prefsbox), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (prefsbox), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (prefsbox))),
 		       2);
@@ -298,18 +296,18 @@ prefsbox_open (void)
 
   /* game tab */
 
-  vbox1 = gtk_vbox_new (FALSE, 18);
+  vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
   gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
   label = gtk_label_new (_("Game"));
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox1, label);
 
-  hbox = gtk_hbox_new (FALSE, 18);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 18);
   gtk_box_pack_start (GTK_BOX (vbox1), hbox, FALSE, FALSE, 0);
 
   frame_player1 = games_frame_new (NULL);
   gtk_box_pack_start (GTK_BOX (hbox), frame_player1, FALSE, FALSE, 0);
 
-  vbox2 = gtk_vbox_new (FALSE, 0);
+  vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add (GTK_CONTAINER (frame_player1), vbox2);
 
   group = NULL;
@@ -322,7 +320,7 @@ prefsbox_open (void)
   frame_player2 = games_frame_new (NULL);
   gtk_box_pack_start (GTK_BOX (hbox), frame_player2, FALSE, FALSE, 0);
 
-  vbox2 = gtk_vbox_new (FALSE, 0);
+  vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_container_add (GTK_CONTAINER (frame_player2), vbox2);
 
   group = NULL;
@@ -335,10 +333,10 @@ prefsbox_open (void)
   frame = games_frame_new (_("Appearance"));
   gtk_box_pack_start (GTK_BOX (vbox1), frame, FALSE, FALSE, 0);
 
-  vbox2 = gtk_vbox_new (FALSE, 7);
+  vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 7);
   gtk_container_add (GTK_CONTAINER (frame), vbox2);
 
-  hbox = gtk_hbox_new (FALSE, 12);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_box_pack_start (GTK_BOX (vbox2), hbox, TRUE, TRUE, 0);
 
   label = gtk_label_new_with_mnemonic (_("_Theme:"));
