@@ -96,10 +96,10 @@ static GamesFileList *theme_list = NULL;
 static GnobotsProperties properties;
 
 static const guint default_keys[N_KEYS] = {
-  GDK_KP_Home, GDK_KP_Up, GDK_KP_Page_Up,
-  GDK_KP_Left, GDK_KP_Begin, GDK_KP_Right,
-  GDK_KP_End, GDK_KP_Down, GDK_KP_Page_Down,
-  GDK_KP_Add, GDK_KP_Multiply, GDK_KP_Enter
+  GDK_KEY_KP_Home, GDK_KEY_KP_Up, GDK_KEY_KP_Page_Up,
+  GDK_KEY_KP_Left, GDK_KEY_KP_Begin, GDK_KEY_KP_Right,
+  GDK_KEY_KP_End, GDK_KEY_KP_Down, GDK_KEY_KP_Page_Down,
+  GDK_KEY_KP_Add, GDK_KEY_KP_Multiply, GDK_KEY_KP_Enter
 };
 
 /**********************************************************************/
@@ -213,11 +213,14 @@ pmap_selection (GtkWidget * widget, gpointer data)
 static void
 type_selection (GtkWidget * widget, gpointer data)
 {
+  gchar *config;
   gint num = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 
   properties.selected_config = num;
 
-  conf_set_configuration (game_config_name (properties.selected_config));
+  config = game_config_name (properties.selected_config);
+  conf_set_configuration (config);
+  g_free (config);
 
   set_game_config (properties.selected_config);
 
@@ -307,6 +310,7 @@ static void
 fill_typemenu (GtkWidget * menu)
 {
   gint i;
+  gchar *config;
 
 #if 0
   /* this is just a place holder so that xgettext can found the strings to
@@ -322,7 +326,9 @@ fill_typemenu (GtkWidget * menu)
 #endif
 
   for (i = 0; i < num_game_configs (); ++i) {
-    gtk_combo_box_append_text (GTK_COMBO_BOX (menu), _(game_config_name (i)));
+    config = game_config_name (i);
+    gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (menu), _(config));
+    g_free (config);
   }
 
   gtk_combo_box_set_active (GTK_COMBO_BOX (menu), properties.selected_config);
@@ -421,7 +427,6 @@ show_properties_dialog (void)
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
 					 NULL);
-  gtk_dialog_set_has_separator (GTK_DIALOG (propbox), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (propbox), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (propbox))), 2);
   /* Set up notebook and add it to hbox of the gtk_dialog */
@@ -434,19 +439,20 @@ show_properties_dialog (void)
               notebook, TRUE, TRUE, 0);
 
   /* The configuration page */
-  cpage = gtk_vbox_new (FALSE, 18);
+  cpage = gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
   gtk_container_set_border_width (GTK_CONTAINER (cpage), 12);
 
   frame = games_frame_new (_("Game Type"));
   gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
 
-  vbox = gtk_vbox_new (FALSE, 6);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
-  hbox = gtk_hbox_new (TRUE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+  gtk_box_set_homogeneous (GTK_BOX (hbox), TRUE);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-  typemenu = gtk_combo_box_new_text ();
+  typemenu = gtk_combo_box_text_new ();
   g_signal_connect (G_OBJECT (typemenu), "changed",
 		    G_CALLBACK (type_selection), NULL);
   fill_typemenu (typemenu);
@@ -454,7 +460,8 @@ show_properties_dialog (void)
 
   frame = games_frame_new (_("Options"));
   gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
-  vbox = gtk_vbox_new (TRUE, 6);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_box_set_homogeneous (GTK_BOX (vbox), TRUE);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
   chkbox = gtk_check_button_new_with_mnemonic (_("_Use safe moves"));
@@ -477,7 +484,8 @@ show_properties_dialog (void)
 
   frame = games_frame_new (_("Sound"));
   gtk_box_pack_start (GTK_BOX (cpage), frame, FALSE, FALSE, 0);
-  vbox = gtk_vbox_new (TRUE, 6);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_box_set_homogeneous (GTK_BOX (vbox), TRUE);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
   chkbox = gtk_check_button_new_with_mnemonic (_("_Enable sounds"));
@@ -493,7 +501,7 @@ show_properties_dialog (void)
 
 
   /* The graphics page */
-  gpage = gtk_vbox_new (FALSE, 18);
+  gpage = gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
   gtk_container_set_border_width (GTK_CONTAINER (gpage), 12);
 
   frame = games_frame_new (_("Graphics Theme"));
@@ -531,12 +539,12 @@ show_properties_dialog (void)
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), gpage, label);
 
   /* The keyboard page */
-  kpage = gtk_vbox_new (FALSE, 18);
+  kpage = gtk_box_new (GTK_ORIENTATION_VERTICAL, 18);
   gtk_container_set_border_width (GTK_CONTAINER (kpage), 12);
 
   frame = games_frame_new (_("Keyboard Controls"));
   gtk_box_pack_start (GTK_BOX (kpage), frame, TRUE, TRUE, 0);
-  vbox = gtk_vbox_new (FALSE, 6);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
 
   controls_list = games_controls_list_new (KEY_PREFERENCES_GROUP);
@@ -593,7 +601,7 @@ load_properties (void)
 {
   gchar *cname = NULL;
   gint i;
-  gchar *bgcolour;
+  gchar *bgcolour, *config;
 
   load_keys ();
 
@@ -610,10 +618,13 @@ load_properties (void)
 
   properties.selected_config = 0;
   for (i = 0; i < num_game_configs (); ++i) {
-    if (!strcmp (cname, game_config_name (i))) {
+    config = game_config_name (i);
+    if (!strcmp (cname, config)) {
+      g_free (config);
       properties.selected_config = i;
       break;
     }
+    g_free (config);
   }
   g_free (cname);
 
@@ -717,13 +728,18 @@ gboolean
 save_properties (void)
 {
   gint i;
+  gchar *config;
 
   for (i = 0; i < 12; i++) {
     conf_set_control_key (i, properties.keys[i]);
   }
 
   conf_set_theme (properties.themename);
-  conf_set_configuration (game_config_name (properties.selected_config));
+
+  config = game_config_name (properties.selected_config);
+  conf_set_configuration (config);
+  g_free (config);
+
   conf_set_use_safe_moves (properties.safe_moves);
   conf_set_use_super_safe_moves (properties.super_safe_moves);
   conf_set_enable_sound (properties.sound);
