@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
-import gtk, pickle, types, os, errno
+from gi.repository import Gtk
+import pickle, types, os, errno
 import defaults
-from gtk_goodies.dialog_extras import show_message
+from gtk_goodies.dialog_extras import show_message_dialog
 from gettext import gettext as _
 import tracker_info
 
@@ -133,15 +134,15 @@ class SudokuTracker:
                 os.makedirs(path)
             except OSError, e:
                 if e.errno == errno.ENOSPC:
-                    show_message(
+                    show_message_dialog(
                         title = _('No Space'),
                         label = _('No space left on disk'),
-                        message_type = gtk.MESSAGE_ERROR,
+                        message_type = Gtk.MessageType.ERROR,
                         sublabel = _('Unable to create data folder %(path)s.') % locals() + '\n' + \
                                    _('There is no disk space left!')
                         )
                 else:
-                    show_message(
+                    show_message_dialog(
                         title = 'Error creating directory',
                         label = 'Error creating directory',
                         sublabel = (_('Unable to create data folder %(path)s.') % locals() + '\n' +
@@ -164,10 +165,10 @@ class SudokuTracker:
             pickle.dump(jar, outfi)
             outfi.close()
         except (OSError, IOError), e:
-            show_message(
+            show_message_dialog(
                 title = _('Unable to save game.'),
                 label = _('Unable to save game.'),
-                message_type = gtk.MESSAGE_ERROR,
+                message_type = Gtk.MessageType.ERROR,
                 sublabel = (_('Unable to save file %(filename)s.') % locals()
                           + '\n' +
                           _('Error %(errno)s: %(error)s') % {
@@ -189,10 +190,10 @@ class SudokuTracker:
             pickle.dump(jar, outfi)
             outfi.close()
         except (OSError, IOError), e:
-            show_message(
+            show_message_dialog(
                 title = _('Unable to mark game as finished.'),
                 label = _('Unable to mark game as finished.'),
-                message_type = gtk.MESSAGE_ERROR,
+                message_type = Gtk.MessageType.ERROR,
                 sublabel = (_('Unable to save file %(filename)s.') % locals() + '\n' +
                           _('Error %(errno)s: %(error)s') % {
                 'errno':e.errno,
@@ -207,10 +208,10 @@ class SudokuTracker:
             ofi.write(jar['game'].split('\n')[0]+'\n')
             ofi.close()
         except (OSError, IOError), e:
-            show_message(
+            show_message_dialog(
                 title = _('Sudoku unable to mark game as finished.'),
                 label = _('Sudoku unable to mark game as finished.'),
-                message_type = gtk.MESSAGE_ERROR,
+                message_type = Gtk.MessageType.ERROR,
                 sublabel = (_('Unable to save file %(filename)s.') % locals() + '\n' +
                           _('Error %(errno)s: %(error)s') % {
                 'errno':e.errno,
