@@ -28,12 +28,11 @@
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libgames-support/games-clock.h>
-#include <libgames-support/games-conf.h>
-#include <libgames-support/games-gtk-compat.h>
 #include <libgames-support/games-help.h>
 #include <libgames-support/games-scores.h>
 #include <libgames-support/games-scores-dialog.h>
 #include <libgames-support/games-runtime.h>
+#include <libgames-support/games-settings.h>
 #include <libgames-support/games-stock.h>
 #include <libgames-support/games-pause-action.h>
 #include <libgames-support/games-fullscreen-action.h>
@@ -55,8 +54,8 @@
 #define SHORT_COUNT 5
 #define DELAY 10
 
-#define KEY_GRID_SIZE     "grid_size"
-#define KEY_CLICK_MOVE    "click_to_move"
+#define KEY_GRID_SIZE     "grid-size"
+#define KEY_CLICK_MOVE    "click-to-move"
 
 #define DEFAULT_WIDTH 320
 #define DEFAULT_HEIGHT 240
@@ -96,6 +95,7 @@ typedef enum
   PLAYING,
 } GameState;
 
+static GSettings *settings;
 static GtkWidget *window = NULL;
 static GtkWidget *statusbar = NULL;
 static GtkWidget *space = NULL;
@@ -999,7 +999,7 @@ create_window (void)
   gtk_window_set_title (GTK_WINDOW (window), _(APPNAME_LONG));
 
   gtk_window_set_default_size (GTK_WINDOW (window), DEFAULT_WIDTH, DEFAULT_HEIGHT);
-  games_conf_add_window (GTK_WINDOW (window), NULL);
+  games_settings_bind_window_state ("/org/gnome/gnotravex/", GTK_WINDOW (window));
   gtk_window_set_resizable (GTK_WINDOW (window), TRUE);
 
   gtk_widget_realize (window);
@@ -1398,7 +1398,7 @@ create_statusbar (void)
 {
   GtkWidget *status_bar, *time_label, *time_box;
 
-  time_box = gtk_hbox_new (FALSE, 0);
+  time_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   time_label = gtk_label_new (_("Time:"));
   gtk_box_pack_start (GTK_BOX (time_box), time_label, FALSE, FALSE, 0);
   time_label = gtk_label_new (" ");
@@ -1637,7 +1637,7 @@ size_cb (GtkAction * action, gpointer data)
   size = newsize;
   update_tile_size (width, height);
   games_scores_set_category (highscores, scorecats[size - 2].key);
-  games_conf_set_integer (NULL, KEY_GRID_SIZE, size);
+  g_settings_set_int (settings, KEY_GRID_SIZE, size);
   gtk_action_activate (new_game_action);
 }
 
@@ -1645,7 +1645,7 @@ static void
 clickmove_toggle_cb(GtkToggleAction * togglebutton, gpointer data)
 {
   click_to_move = gtk_toggle_action_get_active (togglebutton);
-  games_conf_set_boolean (NULL, KEY_CLICK_MOVE, click_to_move);
+  g_settings_set_boolean (settings, KEY_CLICK_MOVE, click_to_move);
 }
 
 static void
@@ -1774,7 +1774,7 @@ int
 main (int argc, char **argv)
 {
   GOptionContext *context;
-  GtkWidget *vbox;
+  GtkWidget *grid;
   GtkWidget *menubar;
   GtkUIManager *ui_manager;
   GtkAccelGroup *accel_group;
@@ -1810,7 +1810,7 @@ main (int argc, char **argv)
 
   g_set_application_name (_(APPNAME_LONG));
 
-  games_conf_initialise (APPNAME);
+  settings = g_settings_new ("org.gnome.gnotravex");
 
   highscores = games_scores_new ("gnotravex",
                                  scorecats, G_N_ELEMENTS (scorecats),
@@ -1831,17 +1831,19 @@ main (int argc, char **argv)
 #endif /* WITH_SMCLIENT */
 
   if (size == -1)
-    size = games_conf_get_integer (NULL, KEY_GRID_SIZE, NULL);
+    size = g_settings_get_int (settings, KEY_GRID_SIZE);
   if (size < 2 || size > 6)
     size = 3;
   games_scores_set_category (highscores, scorecats[size - 2].key);
 
-  click_to_move = games_conf_get_boolean (NULL, KEY_CLICK_MOVE, NULL);
+  click_to_move = g_settings_get_boolean (settings, KEY_CLICK_MOVE);
 
   load_background ();
   create_window ();
 
   space = gtk_drawing_area_new ();
+  gtk_widget_set_hexpand (space, TRUE);
+  gtk_widget_set_vexpand (space, TRUE);
   gtk_widget_set_events (space,
                          GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK
                          | GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK);
@@ -1853,12 +1855,12 @@ main (int argc, char **argv)
 
   menubar = create_menu (ui_manager);
 
-  vbox = gtk_vbox_new (FALSE, 0);
-  gtk_container_add (GTK_CONTAINER (window), vbox);
+  grid = gtk_grid_new ();
+  gtk_container_add (GTK_CONTAINER (window), grid);
 
-  gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), space, TRUE, TRUE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
+  gtk_grid_attach (GTK_GRID (grid), menubar, 0, 0, 1, 1);
+  gtk_grid_attach (GTK_GRID (grid), space, 0, 1, 1, 1);
+  gtk_grid_attach (GTK_GRID (grid), statusbar, 0, 2, 1, 1);
 
   accel_group = gtk_ui_manager_get_accel_group (ui_manager);
   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
@@ -1892,7 +1894,7 @@ main (int argc, char **argv)
 
   gtk_main ();
 
-  games_conf_shutdown ();
+  g_settings_sync();
 
   games_runtime_shutdown ();
 
