@@ -22,7 +22,7 @@ try
 	use_theme_colors = gconf_client.get_bool("/apps/lightsoff/use_theme_colors");
 	
 	if(theme == null)
-		theme = default_theme_name;
+		theme_name = default_theme_name;
 }
 catch(e)
 {
@@ -157,12 +157,6 @@ function show_settings()
 
 function populate_theme_selector(selector)
 {
-	// Since we're using GtkBuilder, we can't make a Gtk.ComboBox.text. Instead,
-	// we'll construct the cell renderer here, once, and use that.
-	var cell = new Gtk.CellRendererText();
-	selector.pack_start(cell, true);
-	selector.add_attribute(cell, "text", 0);
-
 	var i = 0;
 
 	for(var th in themes)
